from django.apps import AppConfig


class ExportPDFConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'django_pdf_actions'
    label = 'django_pdf_actions'
    verbose_name = 'Django PDF Actions Export PDF'
